package core.schedules;

import core.entities.User;
import core.entities.timemanager.AbstractSchedule;
import core.repositories.timemanager.ScheduleRepository;
import core.services.ServiceResult;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.boot.test.autoconfigure.orm.jpa.TestEntityManager;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.jdbc.SqlGroup;
import org.springframework.test.context.junit.jupiter.SpringExtension;

import java.util.Optional;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

@ExtendWith(SpringExtension.class)
@DataJpaTest
public class ScheduleRepositoryTest {

    @Autowired private ScheduleRepository scheduleRepository;
    @Autowired private TestEntityManager entityManager;
    @Test
    @SqlGroup({
            @Sql("classpath:taskgroupRepositoryTestEntries.sql"),
            @Sql("classpath:taskRepositoryEntries.sql"),
            @Sql("classpath:basicScheduleEntries.sql")
    })
    void getAllSchedulesOfUser() {
        User referenceUser_1 = entityManager.find(User.class, 1L);
        User referenceUser_2 = entityManager.find(User.class, 2L);

        assertEquals(0, scheduleRepository.findAllByUsername(referenceUser_2.getUsername()).size());
        assertEquals(5, scheduleRepository.findAllByUsername(referenceUser_1.getUsername()).size());
    }

    @Test
    @SqlGroup({
            @Sql("classpath:taskgroupRepositoryTestEntries.sql"),
            @Sql("classpath:taskRepositoryEntries.sql"),
            @Sql("classpath:basicScheduleEntries.sql")
    })
    void getActiveScheduleOfUser() {
        User referenceUser_1 = entityManager.find(User.class, 1L);
        User referenceUser_2 = entityManager.find(User.class, 2L);

        Optional<AbstractSchedule> result_1 = scheduleRepository.getActiveScheduleOfUser(referenceUser_2.getUsername());
        assertTrue(result_1.isEmpty());

        Optional<AbstractSchedule> result_2 = scheduleRepository.getActiveScheduleOfUser(referenceUser_1.getUsername());
        assertTrue(result_2.isPresent());
    }
}
