import {Component, Inject} from '@angular/core';
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ScheduleInfo, ScheduleService} from "../../../api";
import {MatSnackBar} from "@angular/material/snack-bar";

@Component({
  selector: 'app-missed-schedule-forget-confirmation-dialog',
  templateUrl: './missed-schedule-forget-confirmation-dialog.component.html',
  styleUrls: ['./missed-schedule-forget-confirmation-dialog.component.css']
})
export class MissedScheduleForgetConfirmationDialogComponent {

  constructor(@Inject(MAT_DIALOG_DATA) public missedSchedules: ScheduleInfo[],
              private dialogRef: MatDialogRef<MissedScheduleForgetConfirmationDialogComponent>,
              private scheduleService: ScheduleService,
              private snackbar: MatSnackBar) {
  }


  cancel() {
    this.dialogRef.close();
  }

  confirm() {
    this.scheduleService.schedulesScheduleIDsAllDelete(this.missedSchedules.map(schedule => schedule.scheduleID)).subscribe({
      next: resp => {
        this.dialogRef.close(resp);
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Not found", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "", {duration: 2000});
        }
      }
    })
  }
}
